@@ -20,12 +20,14 @@
 #include <vector>
 
 #include "commons/globals.h"
+#include "Eigen/Sparse"
 #include "forest/ForestPredictors.h"
 #include "forest/ForestTrainers.h"
 #include "RcppUtilities.h"
 
 // [[Rcpp::export]]
 Rcpp::List custom_train(Rcpp::NumericMatrix input_data,
+                        Eigen::SparseMatrix<double> sparse_input_data,
                         size_t outcome_index,
                         std::vector <std::string> variable_names,
                         unsigned int mtry,
@@ -41,7 +43,7 @@ Rcpp::List custom_train(Rcpp::NumericMatrix input_data,
                         bool honesty,
                         unsigned int ci_group_size,
                         double alpha) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
 
   ForestTrainer trainer = ForestTrainers::custom_trainer(data,
           outcome_index - 1,
@@ -58,9 +60,10 @@ Rcpp::List custom_train(Rcpp::NumericMatrix input_data,
 // [[Rcpp::export]]
 Rcpp::NumericMatrix custom_predict(Rcpp::List forest_object,
                                    Rcpp::NumericMatrix input_data,
+                                   Eigen::SparseMatrix<double> sparse_input_data,
                                    std::vector<std::string> variable_names,
                                    unsigned int num_threads) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
@@ -75,9 +78,10 @@ Rcpp::NumericMatrix custom_predict(Rcpp::List forest_object,
 // [[Rcpp::export]]
 Rcpp::NumericMatrix custom_predict_oob(Rcpp::List forest_object,
                                        Rcpp::NumericMatrix input_data,
+                                       Eigen::SparseMatrix<double> sparse_input_data,
                                        std::vector<std::string> variable_names,
                                        unsigned int num_threads) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
