@@ -5,12 +5,14 @@
 
 
 #include "commons/globals.h"
+#include "Eigen/Sparse"
 #include "forest/ForestPredictors.h"
 #include "forest/ForestTrainers.h"
 #include "RcppUtilities.h"
 
 // [[Rcpp::export]]
 Rcpp::List instrumental_train(Rcpp::NumericMatrix input_data,
+                              Eigen::SparseMatrix<double> sparse_input_data,
                               size_t outcome_index,
                               size_t treatment_index,
                               size_t instrument_index,
@@ -31,7 +33,7 @@ Rcpp::List instrumental_train(Rcpp::NumericMatrix input_data,
                               double alpha,
                               double lambda,
                               bool downweight_penalty) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
 
   ForestTrainer trainer = lambda > 0
     ? ForestTrainers::regularized_instrumental_trainer(data,
@@ -60,10 +62,11 @@ Rcpp::List instrumental_train(Rcpp::NumericMatrix input_data,
 // [[Rcpp::export]]
 Rcpp::List instrumental_predict(Rcpp::List forest_object,
                                 Rcpp::NumericMatrix input_data,
+                                Eigen::SparseMatrix<double> sparse_input_data,
                                 std::vector <std::string> variable_names,
                                 unsigned int num_threads,
                                 unsigned int ci_group_size) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
@@ -78,10 +81,11 @@ Rcpp::List instrumental_predict(Rcpp::List forest_object,
 // [[Rcpp::export]]
 Rcpp::List instrumental_predict_oob(Rcpp::List forest_object,
                                     Rcpp::NumericMatrix input_data,
+                                    Eigen::SparseMatrix<double> sparse_input_data,
                                     std::vector <std::string> variable_names,
                                     unsigned int num_threads,
                                     unsigned int ci_group_size) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
