@@ -4,14 +4,16 @@
 #include <vector>
 
 #include "commons/globals.h"
+#include "Eigen/Sparse"
 #include "forest/ForestPredictors.h"
 #include "forest/ForestTrainers.h"
 #include "RcppUtilities.h"
 
 // [[Rcpp::export]]
 Rcpp::List regression_train(Rcpp::NumericMatrix input_data,
+                            Eigen::SparseMatrix<double> sparse_input_data,
                             size_t outcome_index,
-                            std::vector <std::string> variable_names,
+                            std::vector<std::string> variable_names,
                             unsigned int mtry,
                             unsigned int num_trees,
                             bool verbose,
@@ -27,7 +29,7 @@ Rcpp::List regression_train(Rcpp::NumericMatrix input_data,
                             double alpha,
                             double lambda,
                             bool downweight_penalty) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
 
   ForestTrainer trainer = lambda > 0
       ? ForestTrainers::regularized_regression_trainer(data, outcome_index - 1, lambda, downweight_penalty)
@@ -45,10 +47,11 @@ Rcpp::List regression_train(Rcpp::NumericMatrix input_data,
 // [[Rcpp::export]]
 Rcpp::List regression_predict(Rcpp::List forest_object,
                               Rcpp::NumericMatrix input_data,
+                              Eigen::SparseMatrix<double> sparse_input_data,
                               std::vector<std::string> variable_names,
                               unsigned int num_threads,
                               unsigned int ci_group_size) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
@@ -63,10 +66,11 @@ Rcpp::List regression_predict(Rcpp::List forest_object,
 // [[Rcpp::export]]
 Rcpp::List regression_predict_oob(Rcpp::List forest_object,
                                   Rcpp::NumericMatrix input_data,
+                                  Eigen::SparseMatrix<double> sparse_input_data,
                                   std::vector<std::string> variable_names,
                                   unsigned int num_threads,
                                   unsigned int ci_group_size) {
-  Data* data = RcppUtilities::convert_data(input_data, variable_names);
+  Data* data = RcppUtilities::convert_data(input_data, sparse_input_data, variable_names);
   Forest forest = RcppUtilities::deserialize_forest(
       forest_object[RcppUtilities::SERIALIZED_FOREST_KEY]);
 
