@@ -1,5 +1,5 @@
 /*-------------------------------------------------------------------------------
-  This file is part of generalized random forest (grf).
+  This file is part of generalized-random-forest.
 
   grf is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -20,37 +20,22 @@
 #include <stdexcept>
 #include <algorithm>
 #include <iterator>
-
 #include "Data.h"
-#include "utility.h"
 
 Data::Data() :
-  Data(NULL, std::vector<std::string>(), 0, 0) {}
-
-Data::Data(double* data,
-           std::vector<std::string> variable_names,
-           size_t num_rows,
-           size_t num_cols):
-    variable_names(variable_names),
-    num_rows(num_rows),
-    num_rows_rounded(0),
-    num_cols(num_cols),
+    num_rows(0),
+    num_cols(0),
     externalData(true),
     index_data(0),
-    max_num_unique_values(0),
-    data(data) {}
+    max_num_unique_values(0) {}
 
 Data::~Data() {
   if (index_data != 0) {
     delete[] index_data;
   }
-  if (!externalData) {
-    delete[] data;
-  }
 }
 
 bool Data::load_from_file(std::string filename) {
-
   bool result;
 
   // Open input file
@@ -163,12 +148,11 @@ void Data::get_all_values(std::vector<double>& all_values, const std::vector<siz
   all_values.erase(unique(all_values.begin(), all_values.end()), all_values.end());
 }
 
-double Data::get(size_t row, size_t col) const {
-  return data[col * num_rows + row];
+size_t Data::get_index(size_t row, size_t col) const {
+  return index_data[col * num_rows + row];
 }
 
 void Data::sort() {
-
   // Reserve memory
   index_data = new size_t[num_cols * num_rows];
 
@@ -197,10 +181,24 @@ void Data::sort() {
   }
 }
 
-void Data::reserve_memory() {
-  data = new double[num_cols * num_rows];
+double Data::get_unique_data_value(size_t var, size_t index) const {
+  return unique_data_values[var][index];
 }
 
-void Data::set(size_t col, size_t row, double value, bool& error) {
-  data[col * num_rows + row] = value;
+size_t Data::get_num_unique_data_values(size_t var) const {
+  return unique_data_values[var].size();
+}
+
+const std::vector<std::string>& Data::get_variable_names() const {
+  return variable_names;
+}
+size_t Data::get_num_cols() const {
+  return num_cols;
+}
+size_t Data::get_num_rows() const {
+  return num_rows;
+}
+
+size_t Data::get_max_num_unique_values() const {
+  return max_num_unique_values;
 }
